==> trilinos_9.0.3.dfsg.orig.tar.gz: trilinos-9.0.3.dfsg.orig/packages/Sundance/src-std-framework/Elements/SundanceTestFunction.cpp <==
/* @HEADER@ */
// ************************************************************************
// 
//                              Sundance
//                 Copyright (2005) Sandia Corporation
// 
// Copyright (year first published) Sandia Corporation.  Under the terms 
// of Contract DE-AC04-94AL85000 with Sandia Corporation, the U.S. Government 
// retains certain rights in this software.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//                                                                                 
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA                                                                                
// Questions? Contact Kevin Long (krlong@sandia.gov), 
// Sandia National Laboratories, Livermore, California, USA
// 
// ************************************************************************
/* @HEADER@ */

#include "SundanceTestFunction.hpp"
#include "SundanceOut.hpp"
#include "SundanceTabs.hpp"

using namespace SundanceStdMesh;
using namespace SundanceStdFwk;
using namespace SundanceStdFwk::Internal;
using namespace SundanceCore;
using namespace SundanceCore::Internal;
using namespace Teuchos;


TestFunction::TestFunction(const BasisFamily& basis, const string& name)
  : TestFunctionStub(name, vectorDimStructure(basis),
                        rcp(new TestFunctionData(tuple(basis)))), 
    FuncWithBasis(basis)
{;}


TestFunction::TestFunction(const Array<BasisFamily>& basis, const string& name)
  : TestFunctionStub(name, vectorDimStructure(basis),
                        rcp(new TestFunctionData(basis))), 
    FuncWithBasis(basis)
{;}


TestFunction::TestFunction(const BasisFamily& basis, 
                                 const SpectralBasis& spBasis,
                                 const string& name)
  : TestFunctionStub(name, spBasis, vectorDimStructure(basis),
                     rcp(new TestFunctionData(replicate(basis, spBasis.nterms())))), 
    FuncWithBasis(replicate(basis, spBasis.nterms()))
{;}


TestFunction::TestFunction(const Array<BasisFamily>& basis, 
                                 const SpectralBasis& spBasis,
                                 const string& name)
  : TestFunctionStub(name, spBasis, vectorDimStructure(basis),
                     rcp(new TestFunctionData(replicate(basis, spBasis.nterms())))), 
    FuncWithBasis(replicate(basis, spBasis.nterms()))
{;}

==> trilinos_10.0.4.dfsg.orig.tar.gz: trilinos-10.0.4.dfsg.orig/packages/Sundance/src-std-framework/Elements/SundanceTestFunction.cpp <==
/* @HEADER@ */
// ************************************************************************
// 
//                              Sundance
//                 Copyright (2005) Sandia Corporation
// 
// Copyright (year first published) Sandia Corporation.  Under the terms 
// of Contract DE-AC04-94AL85000 with Sandia Corporation, the U.S. Government 
// retains certain rights in this software.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//                                                                                 
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA                                                                                
// Questions? Contact Kevin Long (krlong@sandia.gov), 
// Sandia National Laboratories, Livermore, California, USA
// 
// ************************************************************************
/* @HEADER@ */

#include "SundanceTestFunction.hpp"
#include "SundanceOut.hpp"
#include "SundanceTabs.hpp"

using namespace SundanceStdMesh;
using namespace SundanceStdFwk;
using namespace SundanceStdFwk::Internal;
using namespace SundanceCore;
using namespace SundanceCore;
using namespace Teuchos;


TestFunction::TestFunction(const BasisFamily& basis, const string& name)
  : TestFunctionStub(name, vectorDimStructure(basis)[0].first,
    vectorDimStructure(basis)[0].second,
    rcp(new TestFunctionData(tuple(basis)))), 
    FuncWithBasis(basis)
{;}



TestFunction::TestFunction(const BasisFamily& basis, 
                                 const SpectralBasis& spBasis,
                                 const string& name)
  : TestFunctionStub(name, spBasis, vectorDimStructure(basis)[0].first,
    vectorDimStructure(basis)[0].second,
    rcp(new TestFunctionData(replicate(basis, spBasis.nterms())))), 
    FuncWithBasis(replicate(basis, spBasis.nterms()))
{;}
